<form action="{{ url_for('jsondash.update') }}" class="well clearfix collapse" id="save-json-form" method="POST" role="form">
    <input type="hidden" name="id" value="{{ view.id }}">
    <input type="hidden" name="edit-raw">
    <fieldset>
        <textarea class="form-control" name="config" id="raw-config" cols="30" rows="10">
            {{ view|jsonstring }}
        </textarea>
    </fieldset>
    <br>
    <button class="pull-right btn btn-lg btn-primary">
        <span class="fa fa-check"></span> update config
    </button>
</form>
