/**
 * DataTables
 */

.dataTables_wrapper {
    width: 100%;
    max-width: 100%;
    padding: 1em;
    margin: 0.4em auto;
}

/**
 * D3js
 */

/* Circle Packing */

.node circle {
    fill: rgb(31, 119, 180);
    fill-opacity: .25;
    stroke: rgb(31, 119, 180);
    stroke-width: 1px;
}
.node.leaf circle {
    fill: #FDF59A;
    fill-opacity: 1;
}
.node text {
    font: 10px sans-serif;
}

/**
 * Custom
 */

.singlenum {
    text-align: center;
    font-weight: 100;
    display: block;
}
