<div class="btn-group">
    <button type="button" class="btn btn-default btn-xs dropdown-toggle" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
    Options <span class="caret"></span>
    </button>
    <ul class="dropdown-menu">
        <li>
            <a href="#edit-view-container" data-toggle="collapse">Edit</a>
        </li>
        <li>
            <a href="#save-json-form" data-toggle="collapse">Edit raw JSON</a>
        </li>
    </ul>
</div>
